#!/bin/bash

rundir=$(dirname $0)

BUILDDIR=/tmp/
BINDIR=$rundir/bin

KERNVER=$(uname -r)
KERNDIR=/lib/modules/$KERNVER


cd $rundir

if [ -d "$KERNDIR/kernel" ]; then
    INSTALLDIR=$KERNDIR/kernel/drivers/net
else
    INSTALLDIR=$KERNDIR/net
fi

if [ `id -ur` != 0 ]; then
    echo "Error: You must be root to install the EBSD driver.."
    exit 1
fi

if [ `uname -s` != "Linux" ]; then
    echo "Error: Trying to install Linux Driver on non Linux platform.."
    exit 1
fi

res=0

if [ "$1" = "-u" ]; then
    # UNINSTALL the driver.
    echo "Uninstall EBSD driver ..."
    rm -f /etc/init.d/ebsd
    rm -f /etc/rc?.d/S??ebsd
    rm -f /etc/rc?.d/K??ebsd
    for dir in `find . -type d -maxdepth 1`
    do
        if [ "$dir" != "." ]; then
            moddir=`basename $dir`
            # Install driver module 
            rm -f /lib/modules/$moddir/kernel/drivers/net/ebsd.o
            rm -f /lib/modules/$moddir/kernel/drivers/addon/ebsd/ebsd.o
        fi
    done
    CWD=`pwd`
    rm -rf $CWD
    rm -f /usr/local/sbin/aebsvm
    rm -f /etc/sysconfig/ebsd
    rm -rf /opt/LeftHandNetworks/4.2/EBSD

else
    echo "Installing EBSD driver..."

    for tarFile in *.tar.gz
    do
        echo Extracting: $tarFile
        tar -zxf $tarFile 2>/dev/null
    done
    res=1
    echo ""
    for dir in `find . -type d -maxdepth 1`
    do
        if [ "$dir" != "." ]; then
            moddir=`basename $dir`
            # First remove any old version driver
            rm -f /lib/modules/$moddir/kernel/drivers/net/ebsd.o
            rm -f /sbin/aebsvm
            # Install driver module 
            if [ -d /lib/modules/$moddir ] ; then
                # Make the aebs addon directory
                mkdir -p /lib/modules/$moddir/kernel/drivers/addon/ebsd
                cp $dir/modules/ebsd.o /lib/modules/$moddir/kernel/drivers/addon/ebsd/ebsd.o
            fi
            if [ $? -eq 0 ]; then
                # Install aebsvm in /usr/local/sbin
                mkdir -p /usr/local/sbin
                cp $moddir/sbin/aebsvm /usr/local/sbin
                # Install the ebsd startup script
                cp $moddir/init.d/ebsd /etc/init.d/
                # Install the ebsd user defines script
                if [ -e /etc/sysconfig/ebsd ] ; then
                    ext=$(date +%T.%j.%N)
                    mv /etc/sysconfig/ebsd /etc/sysconfig/ebsd.$ext
                    echo "Saved /etc/sysconfig/ebsd to /etc/sysconfig/ebsd.$ext"
                fi
                cp $moddir/sysconfig/ebsd /etc/sysconfig/
                #Install the ebsd.conf.sample
		cp $moddir/etc/ebsd.conf.sample /etc/
                # If installing on SuSe system
                if [ -e /etc/SuSE-release ]; then
                    chkconfig -s ebsd on
                else # else use default config
                    chkconfig ebsd reset
                fi
                res=0
            fi
        fi
    done
    if [ $res -eq 0 ]; then
        depmod
        echo "EBSD driver installed successfully."
    else
        echo "Errors installing EBSD driver"
        res=1
    fi
    echo ""
fi

exit $res
